cordova.define("com.dianxinos.dxcordova.download.DXCordovaDownload", function(require, exports, module) {

var argscheck = require('cordova/argscheck'),
    channel = require('cordova/channel'),
    utils = require('cordova/utils'),
    exec = require('cordova/exec');

channel.createSticky('onDXCordovaDownloadReady');
//Tell cordova channel to wait on the CordovaInfoReady event
channel.waitForInitialization('onDXCordovaDownloadReady');

var DXCordovaDownloadError = function(code, msg) {
    this.code = code || null;
    this.message = msg || null;
};

DXCordovaDownloadError.ERROR_NOT_INIT = DXCordovaDownloadError.prototype.ERROR_NOT_INIT = 0;
DXCordovaDownloadError.ERROR_INVALID_URL = DXCordovaDownloadError.prototype.ERROR_INVALID_URL = 1;
DXCordovaDownloadError.ERROR_INVALID_ID = DXCordovaDownloadError.prototype.ERROR_INVALID_ID = 2;
DXCordovaDownloadError.ERROR_INTERNEL = DXCordovaDownloadError.prototype.ERROR_INTERNEL = 3;

var DXCordovaDownloadStatus = function(status, url, progress, pkg) {
    this.status = status || null;
    this.url = url || null;
    this.progress = progress || 0;
    this.package = pkg || null;
};

DXCordovaDownloadStatus.DOWNLOAD_SUCCESS = DXCordovaDownloadStatus.prototype.DOWNLOAD_SUCCESS = 1;
DXCordovaDownloadStatus.DOWNLOAD_FAILED = DXCordovaDownloadStatus.prototype.DOWNLOAD_FAILED = 2;
DXCordovaDownloadStatus.DOWNLOAD_CANCELED = DXCordovaDownloadStatus.prototype.DOWNLOAD_CANCELED = 3;
DXCordovaDownloadStatus.DOWNLOAD_STARTED = DXCordovaDownloadStatus.prototype.DOWNLOAD_STARTED = 4;
DXCordovaDownloadStatus.DOWNLOAD_WORKING = DXCordovaDownloadStatus.prototype.DOWNLOAD_WORKING = 5;
DXCordovaDownloadStatus.INSTALL_SUCCESS = DXCordovaDownloadStatus.prototype.INSTALL_SUCCESS = 6;
DXCordovaDownloadStatus.INSTALL_FAILED = DXCordovaDownloadStatus.prototype.INSTALL_FAILED = 7;
DXCordovaDownloadStatus.INSTALL_STARTED = DXCordovaDownloadStatus.prototype.INSTALL_STARTED = 8;

MessageTypeStatus = 0;
MessageTypeError = 1;

var DXCordovaDownload = function () {
    this._id = 0;
    this.url = null;
    this.onprogress = null;
};

var init = function () {
    var downloadStatusEvent = function (info) {
        if (info) {
            info.msgtype = MessageTypeStatus;
            cordova.fireWindowEvent("downloadstatus", info);
        }
    };

    var downloadErrorEvent = function (e) {
        if (e) {
            if (e.code == DXCordovaDownloadStatus.DOWNLOAD_STARTED) {
                DXCordovaDownload.prototype.available = false;
            }
            e.msgtype = MessageTypeError;
            cordova.fireWindowEvent("downloadstatus", e);
        }
    };
    exec(downloadStatusEvent, downloadErrorEvent, 'DXCordovaDownload', 'init', []);
    DXCordovaDownload.prototype.available = true;
    channel.onDXCordovaDownloadReady.fire();
}

init();

DXCordovaDownload.prototype.download = function(downloadInfo, successCallback, errorCallback) {
    argscheck.checkArgs('oFF', 'DXCordovaDownload.download', arguments);
    var self = this;
    var fail = errorCallback && function(e) {
        errorCallback(e);
    }
    var success = function(result) {
        if (result.status == DXCordovaDownloadStatus.DOWNLOAD_WORKING) {
            if (self.onprogress)
                return self.onprogress(result.progress);
        } else {
            successCallback && successCallback(result);
        }
    }
    var callback = function (info) {
        if (self._id == info.id) {
            if (info.msgtype == MessageTypeStatus) {
                var message = new DXCordovaDownloadStatus(info.status, info.url, info.progress, info.package);
                success(message);
            } else if (info.msgtype == MessageTypeError) {
                var message = new DXCordovaDownloadError(info.code, info.msg);
                fail(message);
            }
        }
    }
    addEventListener("downloadstatus", callback, false);
    exec(function (info) {self._id = info.id;}, null, 'DXCordovaDownload', 'downloadStart', [downloadInfo]);
}

DXCordovaDownload.prototype.cancel = function() {
    exec(null, null, 'DXCordovaDownload', 'downloadCancel', [this._id]);
}

DXCordovaDownload.prototype.install = function() {
    exec(null, null, 'DXCordovaDownload', 'installStart', [this._id]);
}

module.exports = DXCordovaDownload;
});