cordova.define("com.dianxinos.dxcordova.dxcordova-info.DXCordovaInfo", function(require, exports, module) {

var argscheck = require('cordova/argscheck'),
    channel = require('cordova/channel'),
    utils = require('cordova/utils'),
    exec = require('cordova/exec');

channel.createSticky('onDXCordovaInfoReady');
// Tell cordova channel to wait on the CordovaInfoReady event
channel.waitForInitialization('onDXCordovaInfoReady');

/**
 * This represents the DX-Cordova Info, and provides properties for inspecting the version, etc.
 * @constructor
 */
function DXCordovaInfo() {
    this.available = false;
    this.version = null;

    var me = this;

    channel.onCordovaReady.subscribe(function() {
        me.getVersionCode(function(info) {
            me.available = true;
            me.version = info.versionCode;
            channel.onDXCordovaInfoReady.fire();
        },function(e) {
            me.available = false;
            utils.alert("[ERROR] Error initializing Cordova: " + e);
        });
    });
}

/**
 * Get DX-Cordova info
 *
 * @param {Function} successCallback The function to call when the heading data is available
 * @param {Function} errorCallback The function to call when there is an error getting the heading data. (OPTIONAL)
 */
DXCordovaInfo.prototype.getVersionCode = function(successCallback, errorCallback) {
    argscheck.checkArgs('fF', 'DXCordovaInfo.getVersionCode', arguments);
    exec(successCallback, errorCallback, "DXCordovaInfo", "getVersionCode", []);
};

DXCordovaInfo.prototype.getInfo = function(params, successCallback, errorCallback) {
    argscheck.checkArgs('sfF', 'DXCordovaInfo.getInfo', arguments);
    exec(successCallback, errorCallback, "DXCordovaInfo", "getInfo", [params]);
};

module.exports = new DXCordovaInfo();
});