cordova.define("com.dianxinos.dxcordova.intent.DXCordovaIntent", function(require, exports, module) {

    var argscheck = require('cordova/argscheck'),
        exec = require('cordova/exec');

    var intent = {
        /**
        * Start an activity by the uri
        *
        * @param {String} uri
        * @param {Function} {Option} error
        *
        * @error JSON_EXCEPTION, MALFORMED_URL_EXCEPTION
        *
        * Example
        *    dxcordova.intent.startActivity("activity:#Intent;component=com.android.mms/.ui.ConversationList;end",
        *                               function (error) {alert(error)});
        *   dxcordova.intent.startActivity("activity:#Intent;component=com.android.mms/.ui.ConversationList;end")
        */
        startActivity: function (uri, failure) {
            argscheck.checkArgs('sFF', 'DXCordovaIntent.startActivity', arguments);
            exec(null, failure, "DXCordovaIntent","startActivity", [uri]);
        },
        /**
         * Start Service by the uri
         *
         * @param {String} uri
         * @param {Function} {Option} error
         *
         * @error JSON_EXCEPTION, MALFORMED_URL_EXCEPTION
         *
         * Example
         *    dxcordova.intent.startService("service:#Intent;component=com.android.mms/.ui.ConversationList;end",
         *                               function (error) {alert(error)});
         *   dxcordova.intent.startService("service:#Intent;component=com.android.mms/.ui.ConversationList;end")
         */
         startService: function (uri, failure) {
             argscheck.checkArgs('sFF', 'DXCordovaIntent.startService', arguments);
             exec(null, failure, "DXCordovaIntent","startService", [uri]);
         },
         /**
          * Send broadcast by the uri
          *
          * @param {String} uri
          * @param {Function} {Option} error
          *
          * @error JSON_EXCEPTION, MALFORMED_URL_EXCEPTION
          *
          * Example
          *    dxcordova.intent.sendBroadcast("broadcast:#Intent;component=com.android.mms/.ui.ConversationList;end",
          *                               function (error) {alert(error)});
          *   dxcordova.intent.sendBroadcast("broadcast:#Intent;component=com.android.mms/.ui.ConversationList;end")
          */
          sendBroadcast: function (uri, failure) {
              argscheck.checkArgs('sFF', 'DXCordovaIntent.sendBroadcast', arguments);
              exec(null, failure, "DXCordovaIntent","sendBroadcast", [uri]);
          },
          /**
           * Query a Intent is exists by the uri
           *
           * @param {String} uri
           * @param {Function} success
           * @param {Function} {Option} failure
           *
           * @return Object.value {Boolean}: The Intent is exists.
           *
           * @error JSON_EXCEPTION, MALFORMED_URL_EXCEPTION
           *
           * Example
           *    dxcordova.intent.query("query:#Intent;component=com.android.mms/.ui.ConversationList;end",
           *                               function (success) {alert(success.value)},
           *                               function (error) {alert(error)});
           *    dxcordova.intent.query("query:#Intent;component=com.android.mms/.ui.ConversationList;end",
           *                               function (success) {alert(success.value)});
           */
          query: function (uri, success, failure) {
              argscheck.checkArgs('sfF', 'DXCordovaIntent.query', arguments);
              exec(success, failure, "DXCordovaIntent","query", [uri]);
           }
    };
    module.exports = intent;
});