cordova.define("com.dianxinos.dxcordova.share.DXCordovaShare", function(require, exports, module) {

    var argscheck = require('cordova/argscheck'),
        utils = require('cordova/utils'),
        exec = require('cordova/exec');

    /**
     * Share a content.
     *
     * @param {Object} content
     *                                  {code:0,
     *                                   type: text/*,
     *                                   subject: Subject,
     *                                   title: Title,
     *                                   text: Text,
     *                                   stream: Stream,
     *                                   chooser: Chooser}
     * @param {Function} {Option} errorCallback
     *
     * @error JSON_EXCEPTION, MALFORMED_URL_EXCEPTION
     *
     * Example
     *    dxcordova.share({code:0,
     *                              type: text/*,
     *                              subject: Subject,
     *                              title: Title,
     *                              text: Text,
     *                              stream: Stream,
     *                              chooser: Chooser},
     *                              function (error) {alert(error)});
     */
    var Share = function (content, errorCallback) {
        argscheck.checkArgs('oFF', 'DXCordovaShare.share', arguments);
        exec(null, errorCallback, "DXCordovaShare","share", [Share.prototype.encodeUri(content)]);
    }

    /**
     * Query an Share is exist.
     *
     * @param {int/Object} uri
     * @param {Function} {Option} successCallback
     * @param {Function} {Option} errorCallback
     *
     * @error JSON_EXCEPTION, MALFORMED_URL_EXCEPTION
     *
     * Example
     *    dxcordova.share.query(0, function () {},
     *                              function (error) {alert(error)});
     *    dxcordova.share.query(0);
     *    dxcordova.share.query({code:0,
     *                              type: text/*,
     *                              subject: Subject,
     *                              title: Title,
     *                              text: Text,
     *                              stream: Stream,
     *                              chooser: Chooser},
     *                              function () {},
     *                              function (error) {alert(error)});
     *   dxcordova.share.query({code:0,
     *                              type: text/*,
     *                              subject: Subject,
     *                              title: Title,
     *                              text: Text,
     *                              stream: Stream,
     *                              chooser: Chooser});
     */
    Share.query = function(code, successCallback, errorCallback) {
        var success = successCallback &&  function(info) {
            if (info.value !== undefined) {
                successCallback(info.value);
            } else {
                successCallback(info.list)
            }
        };
        if (utils.typeName(code) == 'Number') {
            argscheck.checkArgs('NFF', 'DXCordovaShare.query', arguments);
            exec(success, errorCallback, "DXCordovaShare","query", [code]);
        } else {
            argscheck.checkArgs('OFF', 'DXCordovaShare.query', arguments);
            exec(success, errorCallback, "DXCordovaShare","query", [Share.prototype.encodeUri(code)]);
        }
    };

    Share.prototype.encodeUri = function(content) {
        var uri = "share:";
        if (undefined != content.code)
            uri += content.code;
        uri += '?';
        var arrayObject = [];
        for (var key in content) {
            if (key != 'code')
                arrayObject.push(key + '=' + content[key]);
        }
        uri += arrayObject.join('&');
        return uri;
    };

    /**
     * encode an Object to the share uri.
     *
     * @param {Object} content
     *
     * Example
     *   dxcordova.share.encodeUri({code:0,
     *                              type: text/*,
     *                              subject: Subject,
     *                              title: Title,
     *                              text: Text,
     *                              stream: Stream,
     *                              chooser: Chooser});
     */
    Share.encodeUri = Share.prototype.encodeUri;

    module.exports = Share;
});